@@ -1,6 +1,5 @@
 from pydoctor import driver
 import sys, cStringIO
-import py
 
 def geterrtext(*options):
     options = list(options)
@@ -29,7 +28,7 @@ def test_no_do_nothing():
 
 def test_cannot_advance_blank_system():
     err = geterrtext('--make-html')
-    assert 'cannot advance totally blank' in err
+    assert 'forget an --add-package?' in err
 
 def test_invalid_systemclasses():
     err = geterrtext('--system-class')
@@ -40,3 +39,15 @@ def test_invalid_systemclasses():
     assert 'could not import module' in err
     err = geterrtext('--system-class=pydoctor.model.Class')
     assert 'is not a subclass' in err
+
+
+def test_projectbasedir():
+    """
+    The --project-base-dir option should set the projectbasedirectory attribute
+    on the options object.
+    """
+    value = "projbasedirvalue"
+    options, args = driver.parse_args([
+            "--project-base-dir", value])
+    assert options.projectbasedirectory == value
+
